==> graph-frontend-0.3.20.tgz: package/src/api.js <==
var def = require('./imports').default;
var THREE = def.THREE;
var Edge = def.Edge;
var Node = def.Node;
var OrbitControls = def.OrbitControls;
var d3 = def.d3;
var ee = def.ee;
var Utils = require('./utils/utils');

module.exports = function (self) {

  self.pauseLayout = () => {
    self.paused = true;
  };
  window.pause = self.pauseLayout;

  self.resumeLayout = () => {
    self.paused = false;
  };

  self.mapSelectedNodes = () => {
    self.mapNodeAttributes(["degree", "log", "scalexy"], self.selection);
  };

  self.mapAllNodes = () => {
    self.mapNodeAttributes(["degree", "log", "scalexy"]);
  };

  self.pinSelectedNodes = () => {
    self.mapNodeAttributes([true, "", "pinned"], self.selection);
  };

  self.unpinSelectedNodes = () => {
    self.mapNodeAttributes([false, "", "pinned"], self.selection);
  };

  self.setLabelFontSize = (size) => {
    self.graph.forEachNode(function (node) {
      self.changeLabelFontSize(node, size, self.relativeFontSize);
    });
  }

  self.setLabelRelativeSize = (size) => {
    self.relativeFontSize = size;
    self.setLabelFontSize(self.labelSize);
  }

  self.setLabelLength = (numChars) => {
    self.graph.forEachNode(function (node) {
      self.changeLabelLength(node, numChars);
    })
  }

  self.toggleMap = () => {
    self.mapShowing = !self.mapShowing;
  }

  self.showSelectedLabels = () => {
    for (var i = 0; i < self.selection.length; i++) {
      self.selection[i].renderData.textHolder.children[0].element.override = true;
    }
  }

  self.hideSelectedLabels = () => {
    for (var i = 0; i < self.selection.length; i++) {
      self.selection[i].renderData.textHolder.children[0].element.override = false;
    }
  }

  self.hideAllLabels = () => {
    self.graph.forEachNode(function (node) {
      var node = self.graph.getNode(node.id);
      node.renderData.textHolder.children[0].element.override = false;
    });
  }

  self.setCanvasSize = function(size) {
    self.setBoundarySize(size);
  }

  self.setAllNodesShape = function(shape) {
    if (self.selection.length == 0) {
      self.graph.forEachNode(function (node) {
        self.setNodeShape(self.graph.getNode(node.id), shape);
      });
    } else {
      self.selection.forEach(function(node) {
        self.setNodeShape(self.graph.getNode(node.id), shape);
      });
    }
  }

  self.setNodeShape = function(node, shape) {
    if (shape == "square") {
      node.renderData.draw_object.geometry = Utils.make2x2Rect();
      node.renderData.draw_object.children[0].geometry = Utils.make2x2Rect();
    } else if (shape == 'circle') {
      node.renderData.draw_object.geometry = new THREE.CircleGeometry(1, 32);
      node.renderData.draw_object.children[0].geometry = new THREE.CircleGeometry(1, 32);
    } else if (shape == 'triangle') {
      node.renderData.draw_object.geometry = new THREE.CircleGeometry(1, 3);
      node.renderData.draw_object.children[0].geometry = new THREE.CircleGeometry(1, 3);
    } else if (shape == 'pentagon') {
      node.renderData.draw_object.geometry = new THREE.CircleGeometry(1, 5);
      node.renderData.draw_object.children[0].geometry = new THREE.CircleGeometry(1, 5);
    } else if (shape == 'hexagon') {
      node.renderData.draw_object.geometry = new THREE.CircleGeometry(1, 6);
      node.renderData.draw_object.children[0].geometry = new THREE.CircleGeometry(1, 6);
    } else if (shape == 'octagon') {
      node.renderData.draw_object.geometry = new THREE.CircleGeometry(1, 8);
      node.renderData.draw_object.children[0].geometry = new THREE.CircleGeometry(1, 8);
    }
  }
  
  self.getNumSelected = function() {
    if (self.selection.length == self.graph.getNodesCount()) {
      return 0;
    }
    return self.selection.length;
  }

  self.toggleDark = function() {
    self.darkMode = !self.darkMode;
  }

  self.getGraph = function() {
    return self.graph
  }

  self.getNodeList = function() {
    var nodes = [];
    self.graph.forEachNode(function(node) {
      nodes.push(node);
    });
    return nodes
  }

  self.getPositions = function() {
    var poses = {};
    self.graph.forEachNode(function(node) {
      poses[node.id] = [node.x, node.y];
    });
    return poses
  }

  self.getPinPositions = function() {
    var poses = {};
    self.graph.forEachNode(function(node) {
      poses[node.id] = [node.fx, node.fy];
    });
    return poses
  }
  
  var alias = false
  self.toggleAlias = () => {
    // TODO: recreate renderer with new antialias
    // self.init(alias);
    // self.display();
    alias = !alias
  };

  self.dragLastNode = () => {
    self.selectNode(self.lastNode);
  };
  
  var x = 1.0;
  self.lowerRes = () => {
    x -= 0.1;
    self.renderer.setPixelRatio(x);
    self.onWindowResize();
  };

  self.getNeighbors = function(node) {
    if (node) {
      self.addNeighbors(node);
    } else {
      self.addNeighbors(self.rightClickedNode);
    }
  }

  self.toggleNeighborHighlight = function() {
    self.highlightNeighbors = !self.highlightNeighbors;
  }
}

==> graph-frontend-0.3.22.tgz: package/src/api.js <==
var def = require('./imports').default;
var THREE = def.THREE;
var Edge = def.Edge;
var Node = def.Node;
var OrbitControls = def.OrbitControls;
var d3 = def.d3;
var ee = def.ee;

/**
 * These functions are endpoints revealed to Argo frontend
 */
module.exports = function (self) {

  self.pauseLayout = () => {
    self.paused = true;
  };
  window.pause = self.pauseLayout;

  self.resumeLayout = () => {
    self.paused = false;
  };

  self.mapSelectedNodes = () => {
    self.mapNodeAttributes(["degree", "log", "scalexy"], self.selection);
  };

  self.mapAllNodes = () => {
    self.mapNodeAttributes(["degree", "log", "scalexy"]);
  };

  self.pinSelectedNodes = () => {
    self.mapNodeAttributes([true, "", "pinned"], self.selection);
  };

  self.unpinSelectedNodes = () => {
    self.mapNodeAttributes([false, "", "pinned"], self.selection);
  };

  self.setLabelFontSize = (size) => {
    self.graph.forEachNode(function (node) {
      self.changeLabelFontSize(node, size, self.relativeFontSize);
    });
  }

  self.setLabelRelativeSize = (size) => {
    self.relativeFontSize = size;
    self.setLabelFontSize(self.labelSize);
  }

  self.setLabelLength = (numChars) => {
    self.graph.forEachNode(function (node) {
      self.changeLabelLength(node, numChars);
    })
  }

  self.toggleMap = () => {
    self.mapShowing = !self.mapShowing;
  }

  self.showSelectedLabels = () => {
    for (var i = 0; i < self.selection.length; i++) {
      self.selection[i].renderData.textHolder.children[0].element.override = true;
    }
  }

  self.hideSelectedLabels = () => {
    for (var i = 0; i < self.selection.length; i++) {
      self.selection[i].renderData.textHolder.children[0].element.override = false;
    }
  }

  self.hideAllLabels = () => {
    self.graph.forEachNode(function (node) {
      var node = self.graph.getNode(node.id);
      node.renderData.textHolder.children[0].element.override = false;
    });
  }

  self.setCanvasSize = function(size) {
    self.setBoundarySize(size);
  }

  self.setAllNodesShape = function(shape) {
    if (self.selection.length == 0) {
      self.graph.forEachNode(function (node) {
        self.setNodeShape(self.graph.getNode(node.id), shape);
      });
    } else {
      self.selection.forEach(function(node) {
        self.setNodeShape(self.graph.getNode(node.id), shape);
      });
    }
  }

  self.setNodeShape = function(node, shape) {
    if (shape == "square") {
      node.renderData.draw_object.geometry = self.make2x2Rect();
      node.renderData.draw_object.children[0].geometry = self.make2x2Rect();
    } else if (shape == 'circle') {
      node.renderData.draw_object.geometry = new THREE.CircleGeometry(1, 32);
      node.renderData.draw_object.children[0].geometry = new THREE.CircleGeometry(1, 32);
    } else if (shape == 'triangle') {
      node.renderData.draw_object.geometry = new THREE.CircleGeometry(1, 3);
      node.renderData.draw_object.children[0].geometry = new THREE.CircleGeometry(1, 3);
    } else if (shape == 'pentagon') {
      node.renderData.draw_object.geometry = new THREE.CircleGeometry(1, 5);
      node.renderData.draw_object.children[0].geometry = new THREE.CircleGeometry(1, 5);
    } else if (shape == 'hexagon') {
      node.renderData.draw_object.geometry = new THREE.CircleGeometry(1, 6);
      node.renderData.draw_object.children[0].geometry = new THREE.CircleGeometry(1, 6);
    } else if (shape == 'octagon') {
      node.renderData.draw_object.geometry = new THREE.CircleGeometry(1, 8);
      node.renderData.draw_object.children[0].geometry = new THREE.CircleGeometry(1, 8);
    }
  }
  
  self.getNumSelected = function() {
    if (self.selection.length == self.graph.getNodesCount()) {
      return 0;
    }
    return self.selection.length;
  }

  self.toggleDark = function() {
    self.darkMode = !self.darkMode;
  }

  self.getGraph = function() {
    return self.graph
  }

  self.getNodeList = function() {
    var nodes = [];
    self.graph.forEachNode(function(node) {
      nodes.push(node);
    });
    return nodes
  }

  self.getPositions = function() {
    var poses = {};
    self.graph.forEachNode(function(node) {
      poses[node.id] = [node.x, node.y];
    });
    return poses
  }

  self.getPinPositions = function() {
    var poses = {};
    self.graph.forEachNode(function(node) {
      poses[node.id] = [node.fx, node.fy];
    });
    return poses
  }
  
  var alias = false
  self.toggleAlias = () => {
    // TODO: recreate renderer with new antialias
    // self.init(alias);
    // self.display();
    alias = !alias
  };

  self.dragLastNode = () => {
    self.selectNode(self.lastNode);
  };
  
  var x = 1.0;
  self.lowerRes = () => {
    x -= 0.1;
    self.renderer.setPixelRatio(x);
    self.onWindowResize();
  };

  self.getNeighbors = function(node) {
    if (node) {
      self.addNeighbors(node);
    } else {
      self.addNeighbors(self.rightClickedNode);
    }
  }

  self.toggleNeighborHighlight = function() {
    self.highlightNeighbors = !self.highlightNeighbors;
  }
}
